@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -51,6 +51,12 @@
 
 #include "fftw3.h"
 #include "ifftw.h"
+#include "rdft.h"
+
+#ifdef __cplusplus
+extern "C"
+{
+#endif /* __cplusplus */
 
 /* the API ``plan'' contains both the kernel plan and problem */
 struct X(plan_s) {
@@ -95,4 +101,10 @@ void X(mapflags)(planner *, unsigned);
 
 apiplan *X(mkapiplan)(int sign, unsigned flags, problem *prb);
 
+rdft_kind *X(map_r2r_kind)(int rank, const X(r2r_kind) * kind);
+
+#ifdef __cplusplus
+}  /* extern "C" */
+#endif /* __cplusplus */
+
 #endif				/* __API_H__ */
