@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -46,4 +46,8 @@ const char X(version)[] = PACKAGE "-" PACKAGE_VERSION
    "-altivec"
 #endif
 
+#if HAVE_NEON
+   "-neon"
+#endif
+
 ;
