@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *)
 
@@ -124,7 +124,7 @@ let generate n =
 			  CPlus [viioarray; CUminus (byvl vms)]);
 	     Expr_assign (CVar twarray, CPlus [CVar twarray; 
 					       byvl (Integer nt)]);
-	     make_volatile_stride (CVar rs)
+	     make_volatile_stride (2*n) (CVar rs)
 	   ],
 	  Asch asch)])
   in
