@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *)
 
@@ -122,8 +122,8 @@ let generate n =
 					       byvl (CVar sovs)]);
 	     Expr_assign (CVar ioarray, CPlus [CVar ioarray; 
 					       byvl (CVar sovs)]);
-	     make_volatile_stride (CVar istride);
-	     make_volatile_stride (CVar ostride)
+	     make_volatile_stride (4*n) (CVar istride);
+	     make_volatile_stride (4*n) (CVar ostride)
 	   ],
 	  Asch annot)
    ])
