@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2006 Matteo Frigo
- * Copyright (c) 2003, 2006 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
-/* $Id: primes.c,v 1.22 2006-01-08 01:57:16 stevenj Exp $ */
 
 #include "ifftw.h"
 
@@ -28,7 +27,7 @@
    aren't careful we can have errors due to integer overflows. */
 
 /* Compute (x * y) mod p, but watch out for integer overflows; we must
-   have x, y >= 0, p > 0.
+   have 0 <= {x, y} < p.
 
    If overflow is common, this routine is somewhat slower than
    e.g. using 'long long' arithmetic.  However, it has the advantage
@@ -37,7 +36,7 @@
    optimizes for the case of small integers. 
 */
 
-#define ADD_MOD(x, y, p) (x >= p - y) ? (x + (y - p)) : (x + y)
+#define ADD_MOD(x, y, p) ((x) >= (p) - (y)) ? ((x) + ((y) - (p))) : ((x) + (y))
 
 INT X(safe_mulmod)(INT x, INT y, INT p)
 {
@@ -46,6 +45,8 @@ INT X(safe_mulmod)(INT x, INT y, INT p)
      if (y > x) 
 	  return X(safe_mulmod)(y, x, p);
 
+     A(0 <= y && x < p);
+
      r = 0;
      while (y) {
 	  r = ADD_MOD(r, x*(y&1), p); y >>= 1;
@@ -192,3 +193,20 @@ INT X(choose_radix)(INT r, INT n)
 	  return (n > r && divides(r, n)) ? isqrt_maybe(n / r) : 0;
      }
 }
+
+/* return A mod N, works for all A including A < 0 */
+INT X(modulo)(INT a, INT n)
+{
+     A(n > 0);
+     if (a >= 0)
+	  return a % n;
+     else
+	  return (n - 1) - ((-(a + (INT)1)) % n);
+}
+
+/* TRUE if N factors into small primes */
+int X(factors_into_small_primes)(INT n)
+{
+     static const INT primes[] = { 2, 3, 5, 0 };
+     return X(factors_into)(n, primes);
+}
