@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
-/* $Id: scan.c,v 1.17 2003/03/15 20:29:43 stevenj Exp $ */
 
 #include "ifftw.h"
 #include <string.h>
@@ -152,7 +151,8 @@ static int vscan(scanner *sc, const char *format, va_list ap)
 		       }
 		       case 'M': {
 			    md5uint *x = va_arg(ap, md5uint *);
-			    *x = 0xffffffffUL & getlong(sc, 16, &ch);
+			    *x = (md5uint)
+				    (0xffffffffUL & getlong(sc, 16, &ch));
 			    if (!ch) return 0;
 			    break;
 		       }
