@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -63,128 +63,100 @@ typedef enum {
 #define RODFT_KINDP(k) ((k) >= RODFT00 && (k) <= RODFT11)
 #define REODFT_KINDP(k) ((k) >= REDFT00 && (k) <= RODFT11)
 
-/* real-input DFT codelets */
-typedef struct kr2hc_desc_s kr2hc_desc;
+/* codelets with real input (output) and complex output (input) */
+typedef struct kr2c_desc_s kr2c_desc;
 
 typedef struct {
-     int (*okp)(
-	  const kr2hc_desc *desc,
-	  const R *I, const R *ro, const R *io,
-	  int is, int ios, int ros, int vl, int ivs, int ovs);
      rdft_kind kind;
-     int vl;
-} kr2hc_genus;
+     INT vl;
+} kr2c_genus;
 
-struct kr2hc_desc_s {
-     int sz;    /* size of transform computed */
+struct kr2c_desc_s {
+     INT n;    /* size of transform computed */
      const char *nam;
      opcnt ops;
-     const kr2hc_genus *genus;
-     int is;
-     int ros, ios;
-     int ivs;
-     int ovs;
+     const kr2c_genus *genus;
 };
 
-typedef void (*kr2hc) (const R *I, R *ro, R *io, stride is,
-		       stride ros, stride ios, int vl, int ivs, int ovs);
-void X(kr2hc_register)(planner *p, kr2hc codelet, const kr2hc_desc *desc);
-
-/* real-input DFT codelets, type II (middle case of hc2hc DIT) */
-typedef kr2hc_desc kr2hcII_desc;
-typedef kr2hc_genus kr2hcII_genus;
-typedef kr2hc kr2hcII;
-#define kr2hcII_register kr2hc_register
+typedef void (*kr2c) (R *R0, R *R1, R *Cr, R *Ci,
+		      stride rs, stride csr, stride csi,
+		      INT vl, INT ivs, INT ovs);
+void X(kr2c_register)(planner *p, kr2c codelet, const kr2c_desc *desc);
 
 /* half-complex to half-complex DIT/DIF codelets: */
 typedef struct hc2hc_desc_s hc2hc_desc;
 
 typedef struct {
-     int (*okp)(
-	  const struct hc2hc_desc_s *desc,
-	  const R *rio, const R *iio, int ios, int vs, int m, int dist);
      rdft_kind kind;
-     int vl;
+     INT vl;
 } hc2hc_genus;
 
 struct hc2hc_desc_s {
-     int radix;
+     INT radix;
      const char *nam;
      const tw_instr *tw;
-     opcnt ops;
      const hc2hc_genus *genus;
-     int s1;
-     int s2;
-     int dist;
+     opcnt ops;
 };
 
-typedef const R *(*khc2hc) (R *rioarray, R *iioarray, const R *W,
-                              stride ios, int m, int dist);
-void X(khc2hc_dit_register)(planner *p, khc2hc codelet, const hc2hc_desc *desc);
+typedef void (*khc2hc) (R *rioarray, R *iioarray, const R *W,
+			stride rs, INT mb, INT me, INT ms);
+void X(khc2hc_register)(planner *p, khc2hc codelet, const hc2hc_desc *desc);
 
-extern const solvtab X(solvtab_rdft_r2hc);
+/* half-complex to rdft2-complex DIT/DIF codelets: */
+typedef struct hc2c_desc_s hc2c_desc;
 
-/* real-output DFT codelets */
-typedef struct khc2r_desc_s khc2r_desc;
+typedef enum {
+     HC2C_VIA_RDFT,
+     HC2C_VIA_DFT
+} hc2c_kind;
 
 typedef struct {
      int (*okp)(
-	  const khc2r_desc *desc,
-	  const R *ri, const R *ii, const R *O,
-	  int ris, int iis, int os, int vl, int ivs, int ovs);
+	  const R *Rp, const R *Ip, const R *Rm, const R *Im, 
+	  INT rs, INT mb, INT me, INT ms, 
+	  const planner *plnr);
      rdft_kind kind;
-     int vl;
-} khc2r_genus;
+     INT vl;
+} hc2c_genus;
 
-struct khc2r_desc_s {
-     int sz;    /* size of transform computed */
+struct hc2c_desc_s {
+     INT radix;
      const char *nam;
+     const tw_instr *tw;
+     const hc2c_genus *genus;
      opcnt ops;
-     const khc2r_genus *genus;
-     int ris, iis;
-     int os;
-     int ivs;
-     int ovs;
 };
 
-typedef void (*khc2r) (const R *ri, const R *ii, R *O, stride ris,
-		       stride iis, stride os, int vl, int ivs, int ovs);
-void X(khc2r_register)(planner *p, khc2r codelet, const khc2r_desc *desc);
+typedef void (*khc2c) (R *Rp, R *Ip, R *Rm, R *Im, const R *W,
+		       stride rs, INT mb, INT me, INT ms);
+void X(khc2c_register)(planner *p, khc2c codelet, const hc2c_desc *desc,
+		       hc2c_kind hc2ckind);
 
-/* real-output DFT codelets, type III (middle case of hc2hc DIF) */
-typedef khc2r_desc khc2rIII_desc;
-typedef khc2r_genus khc2rIII_genus;
-typedef khc2r khc2rIII;
-#define khc2rIII_register khc2r_register
-
-void X(khc2hc_dif_register)(planner *p, khc2hc codelet, const hc2hc_desc *desc);
-
-extern const solvtab X(solvtab_rdft_hc2r);
+extern const solvtab X(solvtab_rdft_r2cf);
+extern const solvtab X(solvtab_rdft_r2cb);
+extern const solvtab X(solvtab_rdft_sse2);
+extern const solvtab X(solvtab_rdft_avx);
+extern const solvtab X(solvtab_rdft_altivec);
+extern const solvtab X(solvtab_rdft_neon);
 
 /* real-input & output DFT-like codelets (DHT, etc.) */
 typedef struct kr2r_desc_s kr2r_desc;
 
 typedef struct {
-     int (*okp)(
-	  const kr2r_desc *desc,
-	  const R *I, const R *O,
-	  int is, int os, int vl, int ivs, int ovs);
-     int vl;
+     INT vl;
 } kr2r_genus;
 
 struct kr2r_desc_s {
-     int sz;    /* size of transform computed */
+     INT n;    /* size of transform computed */
      const char *nam;
      opcnt ops;
      const kr2r_genus *genus;
      rdft_kind kind;
-     int is, os;
-     int ivs;
-     int ovs;
 };
 
 typedef void (*kr2r) (const R *I, R *O, stride is, stride os,
-		      int vl, int ivs, int ovs);
+		      INT vl, INT ivs, INT ovs);
 void X(kr2r_register)(planner *p, kr2r codelet, const kr2r_desc *desc);
 
 extern const solvtab X(solvtab_rdft_r2r);
