@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -70,4 +70,8 @@ void X(rdft_conf_standard)(planner *p)
      if (X(have_simd_altivec)())
 	  X(solvtab_exec)(X(solvtab_rdft_altivec), p);
 #endif
+#if HAVE_NEON
+     if (X(have_simd_neon)())
+	  X(solvtab_exec)(X(solvtab_rdft_neon), p);
+#endif
 }
