@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -23,6 +23,18 @@
 
 static int threads_inited = 0;
 
+static void threads_register_hooks(void)
+{
+     X(mksolver_ct_hook) = X(mksolver_ct_threads);
+     X(mksolver_hc2hc_hook) = X(mksolver_hc2hc_threads);
+}
+
+static void threads_unregister_hooks(void)
+{
+     X(mksolver_ct_hook) = 0;
+     X(mksolver_hc2hc_hook) = 0;
+}
+
 /* should be called before all other FFTW functions! */
 int X(init_threads)(void)
 {
@@ -32,6 +44,8 @@ int X(init_threads)(void)
           if (X(ithreads_init)())
                return 0;
 
+	  threads_register_hooks();
+
 	  /* this should be the first time the_planner is called,
 	     and hence the time it is configured */
 	  plnr = X(the_planner)();
@@ -42,11 +56,13 @@ int X(init_threads)(void)
      return 1;
 }
 
+
 void X(cleanup_threads)(void)
 {
      X(cleanup)();
      if (threads_inited) {
 	  X(threads_cleanup)();
+	  threads_unregister_hooks();
 	  threads_inited = 0;
      }
 }
@@ -62,5 +78,4 @@ void X(plan_with_nthreads)(int nthreads)
      A(threads_inited);
      plnr = X(the_planner)();
      plnr->nthr = X(imax)(1, nthreads);
-     X(threads_setmax)(plnr->nthr);
 }
